@@ -21,12 +21,12 @@ import (
 	"strings"
 
 	spokeClusterV1 "github.com/open-cluster-management/api/cluster/v1"
+	chv1 "github.com/open-cluster-management/multicloud-operators-channel/pkg/apis/apps/v1"
+	helmsync "github.com/open-cluster-management/multicloud-operators-channel/pkg/synchronizer/helmreposynchronizer"
+	"github.com/open-cluster-management/multicloud-operators-channel/pkg/utils"
 	dplv1 "github.com/open-cluster-management/multicloud-operators-deployable/pkg/apis/apps/v1"
 	dplutils "github.com/open-cluster-management/multicloud-operators-deployable/pkg/utils"
 	placementutils "github.com/open-cluster-management/multicloud-operators-placementrule/pkg/utils"
-	chv1 "github.com/stolostron/multicloud-operators-channel/pkg/apis/apps/v1"
-	helmsync "github.com/stolostron/multicloud-operators-channel/pkg/synchronizer/helmreposynchronizer"
-	"github.com/stolostron/multicloud-operators-channel/pkg/utils"
 
 	"github.com/go-logr/logr"
 	gerr "github.com/pkg/errors"
@@ -420,8 +420,8 @@ func (r *ReconcileChannel) validateClusterRBAC(instance *chv1.Channel, logger lo
 	for _, cl := range cllist.Items {
 		subjects = append(subjects, rbac.Subject{
 			APIGroup: "rbac.authorization.k8s.io",
-			Kind:     "User",
-			Name:     "system:serviceaccount:" + cl.Name + ":" + cl.Name + "-appmgr",
+			Kind:     "Group",
+			Name:     "system:open-cluster-management:cluster:" + cl.Name + ":addon:application-manager",
 		})
 	}
 
