@@ -32,10 +32,10 @@ import (
 	"sigs.k8s.io/controller-runtime/pkg/controller/controllerutil"
 	"sigs.k8s.io/controller-runtime/pkg/log"
 
+	chv1 "github.com/open-cluster-management/multicloud-operators-channel/pkg/apis/apps/v1"
+	"github.com/open-cluster-management/multicloud-operators-channel/pkg/utils"
 	dplv1 "github.com/open-cluster-management/multicloud-operators-deployable/pkg/apis/apps/v1"
 	deputils "github.com/open-cluster-management/multicloud-operators-deployable/pkg/utils"
-	chv1 "github.com/stolostron/multicloud-operators-channel/pkg/apis/apps/v1"
-	"github.com/stolostron/multicloud-operators-channel/pkg/utils"
 )
 
 const syncrhonizerName = "helmrepo"
